@@ -28,6 +28,7 @@ import subprocess
 import sys
 import tempfile
 import warnings
+from collections.abc import Iterable, Mapping
 
 import apport.fileutils
 from apport.packaging_impl import impl as packaging
@@ -506,8 +507,10 @@ def root_command_output(  # pylint: disable=redefined-builtin
     return output
 
 
-def attach_root_command_outputs(report, command_map):
-    """Execute multiple commands as root and put their outputs into report.
+def execute_multiple_root_commands(
+    command_map: Mapping[str, str]
+) -> dict[str, str | bytes]:
+    """Execute multiple commands as root and return their respective outputs.
 
     command_map is a keyname -> 'shell command' dictionary with the commands to
     run. They are all run through /bin/sh, so you need to take care of shell
@@ -520,6 +523,10 @@ def attach_root_command_outputs(report, command_map):
     This is preferable to using root_command_output() multiple times, as that
     will ask for the password every time.
     """
+    if not command_map:
+        return {}
+
+    output: dict[str, bytes | str] = {}
     wrapper_path = os.path.join(
         os.path.abspath(os.environ.get("APPORT_DATA_DIR", "/usr/share/apport")),
         "root_info_wrapper",
@@ -552,17 +559,36 @@ def attach_root_command_outputs(report, command_map):
                 # _root_command_prefix
                 continue
             # opportunistically convert to strings, like command_output()
-            try:
-                buf = buf.decode("UTF-8")
-            except UnicodeDecodeError:
-                pass
             if buf:
-                report[keyname] = buf
-            f.close()
+                try:
+                    output[keyname] = buf.decode("UTF-8")
+                except UnicodeDecodeError:
+                    output[keyname] = buf
+        return output
     finally:
         shutil.rmtree(workdir)
 
 
+def attach_root_command_outputs(
+    report: ProblemReport, command_map: Mapping[str, str]
+) -> None:
+    """Execute multiple commands as root and put their outputs into report.
+
+    command_map is a keyname -> 'shell command' dictionary with the commands to
+    run. They are all run through /bin/sh, so you need to take care of shell
+    escaping yourself. To include stderr output of a command, end it with
+    "2>&1".
+
+    Just like root_command_output, this passes the command through pkexec,
+    unless the caller is already root.
+
+    This is preferable to using root_command_output() multiple times, as that
+    will ask for the password every time.
+    """
+    for k, v in execute_multiple_root_commands(command_map).items():
+        report[k] = v
+
+
 def __filter_re_process(pattern, process):
     lines = ""
     # Get stdout while waiting for process to complete
@@ -792,6 +818,11 @@ def attach_network(report):
             report[var] = os.environ[var]
 
 
+def _get_wireless_devices() -> list[str]:
+    """Return list of wireless devices on the system."""
+    return [p.split("/")[4] for p in glob.glob("/sys/class/net/*/wireless")]
+
+
 def attach_wifi(report):
     """Attach wireless (WiFi) network information to report."""
     report["WifiSyslog"] = recent_syslog(
@@ -800,21 +831,18 @@ def attach_wifi(report):
             r"(\[\d+\])?:"
         )
     )
-    report["IwConfig"] = re.sub(
-        "ESSID:(.*)",
-        "ESSID:<hidden>",
-        re.sub(
-            "Encryption key:(.*)",
-            "Encryption key: <hidden>",
-            re.sub(
-                "Access Point: (.*)",
-                "Access Point: <hidden>",
-                command_output(["iwconfig"]),
-            ),
-        ),
-    )
     report["RfKill"] = command_output(["rfkill", "list"])
     if os.path.exists("/sbin/iw"):
+        for wireless_device in _get_wireless_devices():
+            report[f"IwDev{wireless_device.capitalize()}Link"] = re.sub(
+                "([0-9a-f]{2}:){5}[0-9a-f]{2}",
+                "<hidden-mac>",
+                re.sub(
+                    "SSID: (.*)",
+                    "SSID: <hidden>",
+                    command_output(["iw", "dev", wireless_device, "link"]),
+                ),
+            )
         iw_output = command_output(["iw", "reg", "get"])
     else:
         iw_output = "N/A"
@@ -876,32 +904,42 @@ def attach_printing(report):
     )
 
 
-def attach_mac_events(report, profiles=None):
+def attach_mac_events(
+    report: ProblemReport, profiles: Iterable[str] | str | None = None
+) -> None:
     """Attach MAC information and events to the report."""
     # Allow specifying a string, or a list of strings
     if isinstance(profiles, str):
         profiles = [profiles]
 
-    mac_regex = r"audit\(|apparmor|selinux|security"
+    mac_regex = r"(?:audit\(|apparmor|selinux|security).*"
     mac_re = re.compile(mac_regex, re.IGNORECASE)
     aa_regex = 'apparmor="DENIED".+?profile=([^ ]+?)[ ]'
     aa_re = re.compile(aa_regex, re.IGNORECASE)
 
+    privileged_commands = {}
     if "KernLog" not in report:
-        report["KernLog"] = "\n".join(
-            re.findall(mac_re, root_command_output(["dmesg"]))
-        )
+        privileged_commands["dmesg"] = "dmesg"
 
     if "AuditLog" not in report and os.path.exists("/var/run/auditd.pid"):
-        attach_root_command_outputs(
-            report, {"AuditLog": f'egrep "{mac_regex}" /var/log/audit/audit.log'}
+        privileged_commands["AuditLog"] = (
+            f'egrep "{mac_regex}" /var/log/audit/audit.log'
         )
 
+    privileged_outputs = execute_multiple_root_commands(privileged_commands)
+
+    if "dmesg" in privileged_outputs:
+        output = privileged_outputs["dmesg"]
+        assert isinstance(output, str)
+        report["KernLog"] = "\n".join(re.findall(mac_re, output))
+    if "AuditLog" in privileged_outputs:
+        report["AuditLog"] = privileged_outputs["AuditLog"]
+
     attach_file_if_exists(report, "/proc/version_signature", "ProcVersionSignature")
     attach_file(report, "/proc/cmdline", "ProcCmdline")
 
     for match in re.findall(
-        aa_re, report.get("KernLog", "") + report.get("AuditLog", "")
+        aa_re, "\n".join((report.get("KernLog", ""), report.get("AuditLog", "")))
     ):
         if not profiles:
             report.add_tags(["apparmor"])
