@@ -17,7 +17,7 @@ This is used on Debian and derivatives such as Ubuntu.
 # pylint: disable=invalid-name
 
 # From Python 3.12 on, it doesn't try to evaluate type signatures at runtime
-# anymore. This behaviour is helpful to us as apt_sl.Deb822SourceEntry isn't
+# anymore. This behaviour is helpful to us as Deb822SourceEntry isn't
 # always a valid type, so use the __future__ mechanism to have this behaviour
 # in older versions as well.
 from __future__ import annotations
@@ -45,24 +45,17 @@ import time
 import urllib.error
 import urllib.parse
 import urllib.request
-from collections.abc import Iterator
+from collections.abc import Iterable, Iterator
 
 import apt
 import apt_pkg
-import aptsources.sourceslist as apt_sl
-from aptsources.sourceslist import SourceEntry
+from aptsources.sourceslist import Deb822SourceEntry, SourceEntry
 
 import apport.logging
 from apport.packaging import PackageInfo
 
-WITH_DEB822_SUPPORT = hasattr(apt_sl, "Deb822SourceEntry")
-
-
-# pylint: disable-next=no-member
-def _parse_deb822_sources(source: str) -> list[apt_sl.Deb822SourceEntry]:
-    if not WITH_DEB822_SUPPORT:
-        return []
 
+def _parse_deb822_sources(source: str) -> list[Deb822SourceEntry]:
     sections = []
     current = []
     with open(source, encoding="utf-8") as f:
@@ -74,13 +67,11 @@ def _parse_deb822_sources(source: str) -> list[apt_sl.Deb822SourceEntry]:
             else:
                 if not current:
                     continue
-                # pylint: disable-next=no-member
-                sections.append(apt_sl.Deb822SourceEntry("\n".join(current), source))
+                sections.append(Deb822SourceEntry("\n".join(current), source))
                 current = []
 
         if current:
-            # pylint: disable-next=no-member
-            sections.append(apt_sl.Deb822SourceEntry("\n".join(current), source))
+            sections.append(Deb822SourceEntry("\n".join(current), source))
         return sections
 
 
@@ -97,8 +88,7 @@ def _order_sources(apt_sources: list[str]) -> Iterator[str]:
     yield from sorted(sources)
 
 
-# pylint: disable-next=no-member
-def _load_all_sources(apt_dir: str) -> list[apt_sl.Deb822SourceEntry | SourceEntry]:
+def _load_all_sources(apt_dir: str) -> list[Deb822SourceEntry | SourceEntry]:
     """Given an APT configuration directory (e.g. /etc/apt/), loads up all
     the source data in one easy-to-consume list.
     """
@@ -119,12 +109,31 @@ def _load_all_sources(apt_dir: str) -> list[apt_sl.Deb822SourceEntry | SourceEnt
         if path.endswith(".list"):
             with open(path, encoding="utf-8") as f:
                 sources.extend([SourceEntry(line, path) for line in f])
-        elif path.endswith(".sources") and WITH_DEB822_SUPPORT:
+        elif path.endswith(".sources"):
             sources.extend(_parse_deb822_sources(path))
 
     return sources
 
 
+def _map_mirror_to_arch(uri: str, target_arch: str) -> str:
+    """Map the givin archive mirror URI to a valid one for the givin architecture.
+
+    The Ubuntu archive is split. The primary mirrors only has packages
+    for the amd64 and i386 architectures. The ports mirrors host all
+    remaining architectures.
+    """
+    if target_arch in {"amd64", "i386"}:
+        ports_match = re.match("http://([a-z.]+)?ports.ubuntu.com/ubuntu-ports/?", uri)
+        if ports_match:
+            return f"http://{ports_match.group(1)}archive.ubuntu.com/ubuntu"
+        return uri
+
+    primary_match = re.match("http://([a-z.]+)?archive.ubuntu.com/ubuntu/?$", uri)
+    if primary_match:
+        return f"http://{primary_match.group(1)}ports.ubuntu.com/ubuntu-ports"
+    return uri
+
+
 def _read_mirror_file(uri: str) -> list[str]:
     """Read an apt-transport-mirror configuration file.
 
@@ -159,26 +168,26 @@ class __AptDpkgPackageInfo(PackageInfo):
     """Concrete apport.packaging.PackageInfo class implementation for
     python-apt and dpkg, as found on Debian and derivatives such as Ubuntu."""
 
-    def __init__(self):
-        self._apt_cache = None
-        self._current_release_codename = None
-        self._sandbox_apt_cache = None
-        self._sandbox_apt_cache_arch = None
-        self._contents_dir = None
-        self._mirror = None
-        self._virtual_mapping_obj = None
-        self._contents_mapping_obj = None
+    def __init__(self) -> None:
+        self._apt_cache: apt.Cache | None = None
+        self._current_release_codename: str | None = None
+        self._sandbox_apt_cache: apt.Cache | None = None
+        self._sandbox_apt_cache_arch: str | None = None
+        self._contents_dir: str | None = None
+        self._mirror: str | None = None
+        self._virtual_mapping_obj: dict[str, set[str]] | None = None
+        self._contents_mapping_obj: dict[bytes, bytes] | None = None
         self._launchpad_base = "https://api.launchpad.net/devel"
         self._contents_update = False
 
-    def __del__(self):
+    def __del__(self) -> None:
         try:
             if self._contents_dir:
                 shutil.rmtree(self._contents_dir)
         except AttributeError:
             pass
 
-    def _virtual_mapping(self, configdir):
+    def _virtual_mapping(self, configdir: str) -> dict[str, set[str]]:
         if self._virtual_mapping_obj is not None:
             return self._virtual_mapping_obj
 
@@ -191,7 +200,7 @@ class __AptDpkgPackageInfo(PackageInfo):
 
         return self._virtual_mapping_obj
 
-    def _save_virtual_mapping(self, configdir):
+    def _save_virtual_mapping(self, configdir: str) -> None:
         mapping_file = os.path.join(configdir, "virtual_mapping.pickle")
         if self._virtual_mapping_obj is not None:
             with open(mapping_file, "wb") as fp:
@@ -249,6 +258,7 @@ class __AptDpkgPackageInfo(PackageInfo):
             self._apt_cache = apt.Cache(progress=progress)
         return self._apt_cache
 
+    # pylint: disable-next=too-many-arguments,too-many-positional-arguments
     def _sandbox_cache(
         self,
         aptroot,
@@ -258,7 +268,7 @@ class __AptDpkgPackageInfo(PackageInfo):
         release_codename,
         origins,
         arch,
-    ):  # pylint: disable=too-many-arguments
+    ):
         """Build apt sandbox and return apt.Cache(rootdir=) (initialized
         lazily).
 
@@ -300,11 +310,11 @@ class __AptDpkgPackageInfo(PackageInfo):
             raise ValueError(f"package {package} does not exist")
         return inst.version
 
-    def get_available_version(self, package):
+    def get_available_version(self, package: str) -> str:
         """Return the latest available version of a package."""
         return self._apt_pkg(package).candidate.version
 
-    def get_dependencies(self, package):
+    def get_dependencies(self, package: str) -> list[str]:
         """Return a list of packages a package depends on."""
         cur_ver = self._apt_pkg(package).installed
         if not cur_ver:
@@ -315,7 +325,7 @@ class __AptDpkgPackageInfo(PackageInfo):
             for d in cur_ver.get_dependencies("Depends", "PreDepends", "Recommends")
         ]
 
-    def get_source(self, package):
+    def get_source(self, package: str) -> str:
         """Return the source package name for a package."""
         if self._apt_pkg(package).installed:
             return self._apt_pkg(package).installed.source_name
@@ -323,7 +333,7 @@ class __AptDpkgPackageInfo(PackageInfo):
             return self._apt_pkg(package).candidate.source_name
         raise ValueError(f"package {package} does not exist")
 
-    def get_package_origin(self, package):
+    def get_package_origin(self, package: str) -> str | None:
         """Return package origin.
 
         Return the repository name from which a package was installed, or None
@@ -339,7 +349,7 @@ class __AptDpkgPackageInfo(PackageInfo):
                 return origin.origin
         return None
 
-    def is_distro_package(self, package):
+    def is_distro_package(self, package: str) -> bool:
         """Check if a package is a genuine distro package.
 
         Return True for a native distro package, False if it comes from a
@@ -365,7 +375,7 @@ class __AptDpkgPackageInfo(PackageInfo):
 
         return False
 
-    def is_native_origin_package(self, package):
+    def is_native_origin_package(self, package: str) -> bool:
         """Check if a package originated from a native location.
 
         Return True for a package which came from an origin which is listed in
@@ -446,7 +456,7 @@ class __AptDpkgPackageInfo(PackageInfo):
         try:
             with urllib.request.urlopen(url) as response:
                 content = response.read()
-        except (urllib.error.URLError, urllib.error.HTTPError):
+        except urllib.error.URLError:
             apport.logging.warning("cannot connect to: %s", urllib.parse.unquote(url))
             return None
         except OSError:
@@ -490,7 +500,7 @@ class __AptDpkgPackageInfo(PackageInfo):
             source_files.append(sfu)
         return source_files
 
-    def get_architecture(self, package):
+    def get_architecture(self, package: str) -> str:
         """Return the architecture of a package.
 
         This might differ on multiarch architectures (e. g. an i386 Firefox
@@ -509,7 +519,7 @@ class __AptDpkgPackageInfo(PackageInfo):
             return None
         return [f for f in output.splitlines() if not f.startswith("diverted")]
 
-    def get_modified_files(self, package):
+    def get_modified_files(self, package: str) -> list[str]:
         """Return list of all modified files of a package."""
         # get the maximum mtime of package files that we consider unmodified
         listfile = f"/var/lib/dpkg/info/{package}:{self.get_system_architecture()}.list"
@@ -641,8 +651,13 @@ class __AptDpkgPackageInfo(PackageInfo):
         return match
 
     def get_file_package(
-        self, file, uninstalled=False, map_cachedir=None, release=None, arch=None
-    ):
+        self,
+        file: str,
+        uninstalled: bool = False,
+        map_cachedir: str | None = None,
+        release: str | None = None,
+        arch: str | None = None,
+    ) -> str | None:
         """Return the package a file belongs to.
 
         Return None if the file is not shipped by any package.
@@ -690,7 +705,7 @@ class __AptDpkgPackageInfo(PackageInfo):
 
     @staticmethod
     @functools.cache
-    def get_system_architecture():
+    def get_system_architecture() -> str:
         """Return the architecture of the system, in the notation used by the
         particular distribution."""
         dpkg = subprocess.run(
@@ -700,23 +715,28 @@ class __AptDpkgPackageInfo(PackageInfo):
         assert arch
         return arch
 
-    def get_library_paths(self):
+    @staticmethod
+    @functools.cache
+    def get_native_multiarch_triplet() -> str:
+        """Return the multiarch triplet for the system architecture"""
+        dpkg = subprocess.run(
+            ["dpkg-architecture", "-qDEB_HOST_MULTIARCH"],
+            check=True,
+            text=True,
+            stdout=subprocess.PIPE,
+        )
+        return dpkg.stdout.strip()
+
+    def get_library_paths(self) -> str:
         """Return a list of default library search paths.
 
         The entries should be separated with a colon ':', like for
         $LD_LIBRARY_PATH. This needs to take any multiarch directories into
         account.
         """
-        dpkg = subprocess.run(
-            ["dpkg-architecture", "-qDEB_HOST_MULTIARCH"],
-            check=True,
-            stdout=subprocess.PIPE,
-        )
-        multiarch_triple = dpkg.stdout.decode().strip()
+        return f"/lib/{self.get_native_multiarch_triplet()}:/lib"
 
-        return f"/lib/{multiarch_triple}:/lib"
-
-    def set_mirror(self, url):
+    def set_mirror(self, url: str) -> None:
         """Explicitly set a distribution mirror URL for operations that need to
         fetch distribution files/packages from the network.
 
@@ -830,7 +850,7 @@ class __AptDpkgPackageInfo(PackageInfo):
 
         return root
 
-    def get_kernel_package(self):
+    def get_kernel_package(self) -> str:
         """Return the actual Linux kernel package name.
 
         This is used when the user reports a bug against the "linux" package.
@@ -838,20 +858,105 @@ class __AptDpkgPackageInfo(PackageInfo):
         # TODO: Ubuntu specific
         return f"linux-image-{os.uname()[2]}"
 
+    def _apt_cache_root_dir(
+        self, architecture: str, cache_dir: pathlib.Path | str, release: str
+    ) -> str:
+        """Determine APT cache root directory.
+
+        release is the value of the report's 'DistroRelease' field or
+        "system" in case the current system configuration should be used.
+        """
+        if architecture != self.get_system_architecture():
+            aptroot_arch = architecture
+        else:
+            aptroot_arch = ""
+        return os.path.join(cache_dir, release, aptroot_arch, "apt")
+
+    # pylint: disable-next=too-many-arguments,too-many-positional-arguments
+    def _remove_conflicting_packages(
+        self,
+        package: str,
+        aptroot: str,
+        apt_cache: apt.Cache,
+        candidate: apt.package.Version,
+        archivedir: str,
+        pkg_versions: dict[str, str],
+    ) -> None:
+        # TODO: Split into smaller functions/methods
+        # pylint: disable=too-many-branches,too-many-locals
+        virtual_mapping = self._virtual_mapping(aptroot)
+        # Remember all the virtual packages that this package provides,
+        # so that if we encounter that virtual package as a
+        # Conflicts/Replaces later, we know to remove this package from
+        # the cache.
+        for p in candidate.provides:
+            virtual_mapping.setdefault(p, set()).add(package)
+        conflicts = []
+        if "Conflicts" in candidate.record:
+            conflicts += apt.apt_pkg.parse_depends(candidate.record["Conflicts"])
+        if "Replaces" in candidate.record:
+            conflicts += apt.apt_pkg.parse_depends(candidate.record["Replaces"])
+        for conflict in conflicts:
+            # if the package conflicts with itself its wonky e.g.
+            # gdb in artful
+            if conflict[0][0] == candidate.package.name:
+                continue
+            # apt_pkg.parse_depends needs to handle the or operator,
+            # but as policy states it is invalid to use that in
+            # Replaces/Depends, we can safely choose the first value
+            # here.
+            conflict_pkg, conflict_ver, conflict_comptype = conflict[0]
+            if apt_cache.is_virtual_package(conflict_pkg):
+                try:
+                    providers = virtual_mapping[conflict_pkg]
+                except KeyError:
+                    # We may not have seen the virtual package that
+                    # this conflicts with, so we can assume it's not
+                    # unpacked into the sandbox.
+                    continue
+                for p in providers:
+                    # if the candidate package being installed
+                    # conflicts with but also provides a virtual
+                    # package don't act on the candidate e.g.
+                    # libpam-modules and libpam-mkhomedir in artful
+                    if p == candidate.package.name:
+                        continue
+                    debs = os.path.join(archivedir, f"{p}_*.deb")
+                    for path in glob.glob(debs):
+                        ver = self._deb_version(path)
+                        if apt.apt_pkg.check_dep(ver, conflict_comptype, conflict_ver):
+                            os.unlink(path)
+                    try:
+                        del pkg_versions[p]
+                    except KeyError:
+                        pass
+                del providers
+            else:
+                debs = os.path.join(archivedir, f"{conflict_pkg}_*.deb")
+                for path in glob.glob(debs):
+                    ver = self._deb_version(path)
+                    if apt.apt_pkg.check_dep(ver, conflict_comptype, conflict_ver):
+                        os.unlink(path)
+                        try:
+                            del pkg_versions[conflict_pkg]
+                        except KeyError:
+                            pass
+
+    # pylint: disable-next=too-many-arguments,too-many-positional-arguments
     def install_packages(
         self,
-        rootdir,
-        configdir,
-        release,
-        packages,
-        verbose=False,
-        cache_dir=None,
-        permanent_rootdir=False,
-        architecture=None,
-        origins=None,
-        install_dbg=True,
-        install_deps=False,
-    ):  # pylint: disable=too-many-arguments
+        rootdir: str,
+        configdir: str | None,
+        release: str,
+        packages: list[tuple[str, str | None]],
+        verbose: bool = False,
+        cache_dir: str | None = None,
+        permanent_rootdir: bool = False,
+        architecture: str | None = None,
+        origins: Iterable[str] | None = None,
+        install_dbg: bool = True,
+        install_deps: bool = False,
+    ) -> str:
         # TODO: Split into smaller functions/methods
         # pylint: disable=too-many-branches,too-many-locals
         # pylint: disable=too-many-nested-blocks,too-many-statements
@@ -928,14 +1033,9 @@ class __AptDpkgPackageInfo(PackageInfo):
         # create apt sandbox
         if cache_dir:
             tmp_aptroot = False
-            if architecture != self.get_system_architecture():
-                aptroot_arch = architecture
-            else:
-                aptroot_arch = ""
-            if configdir:
-                aptroot = os.path.join(cache_dir, release, aptroot_arch, "apt")
-            else:
-                aptroot = os.path.join(cache_dir, "system", aptroot_arch, "apt")
+            aptroot = self._apt_cache_root_dir(
+                architecture, cache_dir, release if configdir else "system"
+            )
             if not os.path.isdir(aptroot):
                 os.makedirs(aptroot)
         else:
@@ -948,10 +1048,10 @@ class __AptDpkgPackageInfo(PackageInfo):
         apt.apt_pkg.config.set("Acquire::http::Proxy::api.launchpad.net", "DIRECT")
         apt.apt_pkg.config.set("Acquire::http::Proxy::launchpad.net", "DIRECT")
 
-        if verbose:
-            fetchProgress = apt.progress.text.AcquireProgress()
-        else:
+        if not verbose:
             fetchProgress = apt.progress.base.AcquireProgress()
+        else:
+            fetchProgress = apt.progress.text.AcquireProgress()
         if not tmp_aptroot:
             apt_cache = self._sandbox_cache(
                 aptroot,
@@ -1074,65 +1174,9 @@ class __AptDpkgPackageInfo(PackageInfo):
             real_pkgs.add(pkg)
 
             if permanent_rootdir:
-                virtual_mapping = self._virtual_mapping(aptroot)
-                # Remember all the virtual packages that this package provides,
-                # so that if we encounter that virtual package as a
-                # Conflicts/Replaces later, we know to remove this package from
-                # the cache.
-                for p in candidate.provides:
-                    virtual_mapping.setdefault(p, set()).add(pkg)
-                conflicts = []
-                if "Conflicts" in candidate.record:
-                    conflicts += apt.apt_pkg.parse_depends(
-                        candidate.record["Conflicts"]
-                    )
-                if "Replaces" in candidate.record:
-                    conflicts += apt.apt_pkg.parse_depends(candidate.record["Replaces"])
-                for conflict in conflicts:
-                    # if the package conflicts with itself its wonky e.g.
-                    # gdb in artful
-                    if conflict[0][0] == candidate.package.name:
-                        continue
-                    # apt_pkg.parse_depends needs to handle the or operator,
-                    # but as policy states it is invalid to use that in
-                    # Replaces/Depends, we can safely choose the first value
-                    # here.
-                    conflict = conflict[0]
-                    if apt_cache.is_virtual_package(conflict[0]):
-                        try:
-                            providers = virtual_mapping[conflict[0]]
-                        except KeyError:
-                            # We may not have seen the virtual package that
-                            # this conflicts with, so we can assume it's not
-                            # unpacked into the sandbox.
-                            continue
-                        for p in providers:
-                            # if the candidate package being installed
-                            # conflicts with but also provides a virtual
-                            # package don't act on the candidate e.g.
-                            # libpam-modules and libpam-mkhomedir in artful
-                            if p == candidate.package.name:
-                                continue
-                            debs = os.path.join(archivedir, f"{p}_*.deb")
-                            for path in glob.glob(debs):
-                                ver = self._deb_version(path)
-                                if apt.apt_pkg.check_dep(ver, conflict[2], conflict[1]):
-                                    os.unlink(path)
-                            try:
-                                del pkg_versions[p]
-                            except KeyError:
-                                pass
-                        del providers
-                    else:
-                        debs = os.path.join(archivedir, f"{conflict[0]}_*.deb")
-                        for path in glob.glob(debs):
-                            ver = self._deb_version(path)
-                            if apt.apt_pkg.check_dep(ver, conflict[2], conflict[1]):
-                                os.unlink(path)
-                                try:
-                                    del pkg_versions[conflict[0]]
-                                except KeyError:
-                                    pass
+                self._remove_conflicting_packages(
+                    pkg, aptroot, apt_cache, candidate, archivedir, pkg_versions
+                )
 
             if candidate.architecture != "all" and install_dbg:
                 try:
@@ -1407,7 +1451,7 @@ class __AptDpkgPackageInfo(PackageInfo):
     #
 
     @staticmethod
-    def _call_dpkg(args):
+    def _call_dpkg(args: list[str]) -> str:
         """Call dpkg with given arguments and return output, or return None on
         error."""
         dpkg = subprocess.run(
@@ -1418,27 +1462,21 @@ class __AptDpkgPackageInfo(PackageInfo):
         raise ValueError("package does not exist")
 
     @staticmethod
-    def _check_files_md5(sumfile):
+    def _check_files_md5(sumfile: bytes) -> list[str]:
         """Call md5sum.
 
         This is separate from get_modified_files so that it is automatically
         testable.
         """
-        if os.path.exists(sumfile):
-            args = [sumfile]
-            stdin = None
-        else:
-            assert isinstance(sumfile, bytes), "md5sum list value must be a byte array"
-            args = []
-            stdin = sumfile
+        env: dict[str, str] = {}
         md5sum = subprocess.run(
-            ["/usr/bin/md5sum", "-c"] + args,
+            ["/usr/bin/md5sum", "-c"],
             check=False,
-            input=stdin,
+            input=sumfile,
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
             cwd="/",
-            env={},
+            env=env,
         )
 
         # if md5sum succeeded, don't bother parsing the output
@@ -1482,7 +1520,7 @@ class __AptDpkgPackageInfo(PackageInfo):
             f" couldn't find configured source contains the `deb` type in {apt_dir}"
         )
 
-    def _get_mirror(self):
+    def _get_mirror(self, arch: str) -> str:
         """Return the distribution mirror URL.
 
         If it has not been set yet, it will be read from the system
@@ -1490,12 +1528,12 @@ class __AptDpkgPackageInfo(PackageInfo):
         """
         if not self._mirror:
             self._mirror = self._get_primary_mirror_from_apt_sources("/etc/apt")
-        return self._mirror
+        return _map_mirror_to_arch(self._mirror, arch)
 
     def _ppa_archive_url(self, user: str, distro: str, ppa_name: str) -> str:
         return f"{self._launchpad_base}/~{user}/+archive/{distro}/{ppa_name}"
 
-    def _distro_release_to_codename(self, release):
+    def _distro_release_to_codename(self, release: str) -> str:
         """Map a DistroRelease: field value to a release code name."""
         # if we called install_packages() with a configdir, we can read the
         # codename from there
@@ -1511,7 +1549,7 @@ class __AptDpkgPackageInfo(PackageInfo):
         self, contents_filename: str, mtime: float | None, dist: str, arch: str
     ) -> bool:
         update = False
-        url = f"{self._get_mirror()}/dists/{dist}/Contents-{arch}.gz"
+        url = f"{self._get_mirror(arch)}/dists/{dist}/Contents-{arch}.gz"
         if mtime:
             # HTTPConnection requires server name e.g.
             # archive.ubuntu.com
@@ -1575,42 +1613,22 @@ class __AptDpkgPackageInfo(PackageInfo):
     def _update_given_file2pkg_mapping(
         file2pkg: dict[bytes, bytes], contents_filename: str, dist: str
     ) -> None:
+        path_exclude_pattern = re.compile(
+            rb"^:|(boot|var|usr/(include|src|[^/]+/include"
+            rb"|share/(doc|gocode|help|icons|locale|man|texlive)))/"
+        )
         with gzip.open(contents_filename, "rb") as contents:
-            line_num = 0
-            for line in contents:
-                line_num += 1
+            if dist in {"trusty", "xenial"}:
                 # the first 32 lines are descriptive only for these
                 # releases
-                if dist in {"trusty", "xenial"} and line_num < 33:
-                    continue
-                path = line.split()[0]
-                if path.split(b"/")[0] == b"usr":
-                    if path.split(b"/")[1] not in (
-                        b"lib",
-                        b"libexec",
-                        b"libx32",
-                        b"bin",
-                        b"sbin",
-                        b"share",
-                        b"games",
-                        b"Brother",
-                    ):
-                        continue
-                    if path.split(b"/")[1] == b"share" and path.split(b"/")[2] in {
-                        b"doc",
-                        b"icons",
-                        b"man",
-                        b"texlive",
-                        b"gocode",
-                        b"locale",
-                        b"help",
-                    }:
-                        continue
-                    package = line.split()[-1].split(b",")[0].split(b"/")[-1]
-                elif path.split(b"/")[0] in {b"lib", b"bin", b"sbin", b"etc"}:
-                    package = line.split()[-1].split(b",")[0].split(b"/")[-1]
-                else:
+                for _ in range(32):
+                    next(contents)
+
+            for line in contents:
+                if path_exclude_pattern.match(line):
                     continue
+                path, column2 = line.rsplit(maxsplit=1)
+                package = column2.split(b",")[0].split(b"/")[-1]
                 if path in file2pkg:
                     if package == file2pkg[path]:
                         continue
@@ -1641,7 +1659,9 @@ class __AptDpkgPackageInfo(PackageInfo):
                 self._update_given_file2pkg_mapping(file2pkg, contents_filename, dist)
         return file2pkg
 
-    def _search_contents(self, file, map_cachedir, release, arch):
+    def _search_contents(
+        self, file: str, map_cachedir: str | None, release: str | None, arch: str | None
+    ) -> str | None:
         """Search file in Contents.gz."""
         if not map_cachedir:
             if not self._contents_dir:
@@ -1662,8 +1682,6 @@ class __AptDpkgPackageInfo(PackageInfo):
             # the update of the mapping only needs to be done once
             self._contents_update = False
 
-        if isinstance(file, bytes):
-            file = file.decode()
         if file[0] != "/":
             file = f"/{file}"
         files = [file[1:].encode()]
@@ -1709,7 +1727,7 @@ class __AptDpkgPackageInfo(PackageInfo):
                 ) as response:
                     response.read()
                     return user, ppa_name
-            except (urllib.error.URLError, urllib.error.HTTPError):
+            except urllib.error.URLError:
                 index += 1
                 if index == len(components):
                     if try_ppa:
@@ -1718,10 +1736,9 @@ class __AptDpkgPackageInfo(PackageInfo):
                         index = 2
         return None
 
-    # pylint: disable-next=no-member
     def create_ppa_source_from_origin(
         self, origin: str, distro: str, release_codename: str
-    ) -> list[apt_sl.Deb822SourceEntry | SourceEntry] | None:
+    ) -> list[Deb822SourceEntry | SourceEntry] | None:
         """For an origin from a Launchpad PPA create sources.list content.
 
         distro is the distribution for which content is being created e.g.
@@ -1741,41 +1758,23 @@ class __AptDpkgPackageInfo(PackageInfo):
             f"/dists/{release_codename}/main/debug"
         )
 
-        if WITH_DEB822_SUPPORT:
-            main_entry = apt_sl.Deb822SourceEntry(None, "")
-            main_entry.uris = [f"http://ppa.launchpad.net/{user}/{ppa_name}/{distro}"]
-            main_entry.types = ["deb", "deb-src"]
-            main_entry.comps = ["main"]
-            main_entry.suites = [release_codename]
+        main_entry = Deb822SourceEntry(None, "")
+        main_entry.uris = [f"http://ppa.launchpad.net/{user}/{ppa_name}/{distro}"]
+        main_entry.types = ["deb", "deb-src"]
+        main_entry.comps = ["main"]
+        main_entry.suites = [release_codename]
 
-            try:
-                with contextlib.closing(urllib.request.urlopen(debug_url)) as response:
-                    response.read()
-                debug_entry = apt_sl.Deb822SourceEntry(None, "")
-                debug_entry.uris = [
-                    f"http://ppa.launchpad.net/{user}/{ppa_name}/{distro}"
-                ]
-                debug_entry.types = ["deb"]
-                debug_entry.comps = ["main/debug"]
-                debug_entry.suites = [release_codename]
-                return [main_entry, debug_entry]
-            except (urllib.error.URLError, urllib.error.HTTPError):
-                return [main_entry]
-        else:
-            ppa_line = (
-                f"deb http://ppa.launchpad.net/{user}/{ppa_name}/{distro}"
-                f" {release_codename} main"
-            )
-            try:
-                with contextlib.closing(urllib.request.urlopen(debug_url)) as response:
-                    response.read()
-                add_debug = " main/debug"
-            except (urllib.error.URLError, urllib.error.HTTPError):
-                add_debug = ""
-            return [
-                SourceEntry(ppa_line + add_debug),
-                SourceEntry(f"deb-src {ppa_line[4:]}"),
-            ]
+        try:
+            with contextlib.closing(urllib.request.urlopen(debug_url)) as response:
+                response.read()
+            debug_entry = Deb822SourceEntry(None, "")
+            debug_entry.uris = [f"http://ppa.launchpad.net/{user}/{ppa_name}/{distro}"]
+            debug_entry.types = ["deb"]
+            debug_entry.comps = ["main/debug"]
+            debug_entry.suites = [release_codename]
+            return [main_entry, debug_entry]
+        except urllib.error.URLError:
+            return [main_entry]
 
     @staticmethod
     def _find_source_file_from_origin(origin: str, src_list_d: str) -> str | None:
@@ -1785,14 +1784,16 @@ class __AptDpkgPackageInfo(PackageInfo):
             # check to see if there is a sources.list file for the
             # origin, if there isn't try using a sources.list file
             # w/o LP-PPA-
-            candidates = [os.path.join(src_list_d, f"{origin}.list")]
-            if WITH_DEB822_SUPPORT:
-                candidates[0:0] = [os.path.join(src_list_d, f"{origin}.source")]
+            candidates = [
+                os.path.join(src_list_d, f"{origin}.source"),
+                os.path.join(src_list_d, f"{origin}.list"),
+            ]
             if "LP-PPA" in origin:
                 stripped = origin.strip("LP-PPA-")
-                if WITH_DEB822_SUPPORT:
-                    candidates.append(os.path.join(f"{stripped}.source"))
-                candidates.append(os.path.join(f"{stripped}.list"))
+                candidates += [
+                    os.path.join(f"{stripped}.source"),
+                    os.path.join(f"{stripped}.list"),
+                ]
 
             for path in candidates:
                 if os.path.exists(path):
@@ -1800,8 +1801,13 @@ class __AptDpkgPackageInfo(PackageInfo):
         return None
 
     def _build_apt_sandbox(
-        self, apt_root, apt_dir, distro_name, release_codename, origins
-    ):
+        self,
+        apt_root: str,
+        apt_dir: str,
+        distro_name: str,
+        release_codename: str,
+        origins: Iterable[str] | None,
+    ) -> None:
         # TODO: Split into smaller functions/methods
         # pylint: disable=too-many-branches,too-many-locals,too-many-statements
 
@@ -1864,19 +1870,16 @@ class __AptDpkgPackageInfo(PackageInfo):
                     continue
                 origin_path = self._find_source_file_from_origin(origin, src_list_d)
                 extension = ".sources"
-                if origin_path:
-                    if origin_path.endswith(".list"):
-                        extension = ".list"
-                        with open(origin_path, encoding="utf-8") as src:
-                            source_list_content = [SourceEntry(line) for line in src]
-                    else:
-                        source_list_content = _parse_deb822_sources(origin_path)
-                else:
+                if not origin_path:
                     source_list_content = self.create_ppa_source_from_origin(
                         origin, distro_name, release_codename
                     )
-                    if not WITH_DEB822_SUPPORT:
-                        extension = ".list"
+                elif origin_path.endswith(".list"):
+                    extension = ".list"
+                    with open(origin_path, encoding="utf-8") as src:
+                        source_list_content = [SourceEntry(line) for line in src]
+                else:
+                    source_list_content = _parse_deb822_sources(origin_path)
                 if source_list_content:
                     with open(
                         os.path.join(
@@ -1935,7 +1938,7 @@ class __AptDpkgPackageInfo(PackageInfo):
                     )
 
     @staticmethod
-    def _deb_version(pkg):
+    def _deb_version(pkg: str) -> str:
         """Return the version of a .deb file."""
         dpkg = subprocess.run(
             ["dpkg-deb", "-f", pkg, "Version"], check=True, stdout=subprocess.PIPE
@@ -1944,7 +1947,7 @@ class __AptDpkgPackageInfo(PackageInfo):
         assert out
         return out
 
-    def compare_versions(self, ver1, ver2):
+    def compare_versions(self, ver1: str, ver2: str) -> int:
         """Compare two package versions.
 
         Return -1 for ver < ver2, 0 for ver1 == ver2, and 1 for ver1 > ver2.
@@ -1953,7 +1956,7 @@ class __AptDpkgPackageInfo(PackageInfo):
 
     _distro_codename = None
 
-    def get_distro_codename(self):
+    def get_distro_codename(self) -> str:
         """Get "lsb_release -sc", cache the result."""
         if self._distro_codename is None:
             try:
@@ -1973,7 +1976,7 @@ class __AptDpkgPackageInfo(PackageInfo):
 
     _distro_name = None
 
-    def get_distro_name(self):
+    def get_distro_name(self) -> str:
         """Get osname from /etc/os-release, or if that doesn't exist,
         'lsb_release -sir' output and cache the result."""
         if self._distro_name is None:
