@@ -18,17 +18,57 @@ import apport.hookutils
 import apport.report
 import problem_report
 from tests.helper import skip_if_command_is_missing
+from tests.paths import local_test_environment
 
 
 class T(unittest.TestCase):
     """Integration tests for the apport.hookutils module."""
 
+    orig_environ: dict[str, str]
+
+    @classmethod
+    def setUpClass(cls) -> None:
+        cls.orig_environ = os.environ.copy()
+        os.environ |= local_test_environment()
+
+    @classmethod
+    def tearDownClass(cls) -> None:
+        os.environ.clear()
+        os.environ.update(cls.orig_environ)
+
     def setUp(self) -> None:
         self.workdir = tempfile.mkdtemp()
 
     def tearDown(self) -> None:
         shutil.rmtree(self.workdir)
 
+    @unittest.mock.patch(
+        "apport.hookutils._root_command_prefix", MagicMock(return_value=[])
+    )
+    def test_attach_root_command_outputs(self) -> None:
+        """attach_root_command_outputs()
+
+        To not require root for this test, execute only commands that do
+        not need root and mock _root_command_prefix().
+        """
+        report = problem_report.ProblemReport()
+        command_map = {
+            "BinaryBlob": r"printf '\303\050'",
+            "EchoFoo": "echo foo",
+            "EchoNothing": "echo",
+            "EchoUnicode": "echo 'hä?'",
+        }
+
+        apport.hookutils.attach_root_command_outputs(report, command_map)
+
+        self.assertEqual(report["BinaryBlob"], b"\303\050")
+        self.assertEqual(report["EchoFoo"], "foo")
+        self.assertEqual(report["EchoUnicode"], "hä?")
+        self.assertEqual(
+            set(report.keys()),
+            {"Date", "BinaryBlob", "EchoFoo", "EchoUnicode", "ProblemType"},
+        )
+
     @skip_if_command_is_missing("/usr/bin/as")
     def test_module_license_evaluation(self) -> None:
         """Module licenses can be validated correctly."""
@@ -207,152 +247,6 @@ class T(unittest.TestCase):
         ):
             self.assertNotEqual(len(apport.hookutils.recent_syslog(re.compile("."))), 0)
 
-    @unittest.mock.patch(
-        "apport.hookutils._root_command_prefix", MagicMock(return_value=[])
-    )
-    def test_attach_mac_events(self) -> None:
-        # TODO: Split into separate test cases
-        # pylint: disable=too-many-statements
-        """attach_mac_events()"""
-        denied_log = (
-            "[  351.624338] type=1400 audit(1343775571.688:27):"
-            ' apparmor="DENIED" operation="capable" parent=1'
-            ' profile="/usr/sbin/cupsd" pid=1361 comm="cupsd" pid=1361'
-            ' comm="cupsd" capability=36  capname="block_suspend"\n'
-        )
-
-        denied_hex = (
-            "[  351.624338] type=1400 audit(1343775571.688:27):"
-            ' apparmor="DENIED" operation="capable" parent=1'
-            ' profile=2F7573722F7362696E2F6375707364 pid=1361 comm="cupsd"'
-            ' pid=1361 comm="cupsd" capability=36  capname="block_suspend"\n'
-        )
-
-        report = problem_report.ProblemReport()
-        apport.hookutils.attach_mac_events(report)
-        self.assertIn("KernLog", report)
-
-        # No AppArmor messages
-        report = problem_report.ProblemReport()
-        report["KernLog"] = (
-            "[    2.997534] i915 0000:00:02.0:"
-            " power state changed by ACPI to D0\n"
-            "[    2.997541] i915 0000:00:02.0:"
-            " PCI INT A -> GSI 16 (level, low)\n"
-            "[    2.997544] i915 0000:00:02.0: setting latency timer to 64\n"
-            "[    3.061584] i915 0000:00:02.0: irq 42 for MSI/MSI-X\n"
-        )
-
-        apport.hookutils.attach_mac_events(report)
-        self.assertNotIn("Tags", report)
-
-        # AppArmor message, but not a denial
-        report = problem_report.ProblemReport()
-        report["KernLog"] = (
-            "[   32.420248] type=1400 audit(1344562672.449:2):"
-            ' apparmor="STATUS" operation="profile_load" name="/sbin/dhclient"'
-            ' pid=894 comm="apparmor_parser"\n'
-        )
-
-        apport.hookutils.attach_mac_events(report)
-        self.assertNotIn("Tags", report)
-
-        # AppArmor denial, empty tags, no profile specified
-        report = problem_report.ProblemReport()
-        report["KernLog"] = denied_log
-
-        apport.hookutils.attach_mac_events(report)
-        self.assertEqual(report["Tags"], "apparmor")
-
-        # AppArmor hex-encoded denial, no profile specified
-        report = problem_report.ProblemReport()
-        report["KernLog"] = denied_hex
-
-        apport.hookutils.attach_mac_events(report)
-        self.assertEqual(report["Tags"], "apparmor")
-
-        # AppArmor denial in AuditLog
-        report = problem_report.ProblemReport()
-        report["AuditLog"] = denied_log
-
-        apport.hookutils.attach_mac_events(report)
-        self.assertEqual(report["Tags"], "apparmor")
-
-        # AppArmor denial, pre-existing tags, no profile specified
-        report = problem_report.ProblemReport()
-        report["KernLog"] = denied_log
-        report["Tags"] = "bogustag"
-
-        apport.hookutils.attach_mac_events(report)
-        self.assertEqual(report["Tags"], "apparmor bogustag")
-
-        # AppArmor denial, single profile specified
-        report = problem_report.ProblemReport()
-        report["KernLog"] = denied_log
-
-        apport.hookutils.attach_mac_events(report, "/usr/sbin/cupsd")
-        self.assertEqual(report["Tags"], "apparmor")
-
-        # AppArmor denial, regex profile specified
-        report = problem_report.ProblemReport()
-        report["KernLog"] = denied_log
-
-        apport.hookutils.attach_mac_events(report, "/usr/sbin/cups.*")
-        self.assertEqual(report["Tags"], "apparmor")
-
-        # AppArmor denial, subset profile specified
-        report = problem_report.ProblemReport()
-        report["KernLog"] = denied_log
-
-        apport.hookutils.attach_mac_events(report, "/usr/sbin/cup")
-        self.assertNotIn("Tags", report)
-
-        # AppArmor hex-encoded denial, single profile specified
-        report = problem_report.ProblemReport()
-        report["KernLog"] = denied_hex
-
-        apport.hookutils.attach_mac_events(report, "/usr/sbin/cupsd")
-        self.assertEqual(report["Tags"], "apparmor")
-
-        # AppArmor denial, single different profile specified
-        report = problem_report.ProblemReport()
-        report["KernLog"] = denied_log
-
-        apport.hookutils.attach_mac_events(report, "/usr/sbin/nonexistent")
-        self.assertNotIn("Tags", report)
-
-        # AppArmor denial, multiple profiles specified
-        report = problem_report.ProblemReport()
-        report["KernLog"] = denied_log
-        profiles = ["/usr/bin/nonexistent", "/usr/sbin/cupsd"]
-
-        apport.hookutils.attach_mac_events(report, profiles)
-        self.assertEqual(report["Tags"], "apparmor")
-
-        # AppArmor denial, multiple different profiles
-        report = problem_report.ProblemReport()
-        report["KernLog"] = denied_log
-        profiles = ["/usr/bin/nonexistent", "/usr/sbin/anotherone"]
-
-        apport.hookutils.attach_mac_events(report, profiles)
-        self.assertNotIn("Tags", report)
-
-        # Multiple AppArmor denials, second match
-        report = problem_report.ProblemReport()
-        report["KernLog"] = (
-            "[  351.624338] type=1400 audit(1343775571.688:27):"
-            ' apparmor="DENIED" operation="capable" parent=1'
-            ' profile="/usr/sbin/blah" pid=1361 comm="cupsd" pid=1361'
-            ' comm="cupsd" capability=36  capname="block_suspend"\n'
-            "[  351.624338] type=1400 audit(1343775571.688:27):"
-            ' apparmor="DENIED" operation="capable" parent=1'
-            ' profile="/usr/sbin/cupsd" pid=1361 comm="cupsd" pid=1361'
-            ' comm="cupsd" capability=36  capname="block_suspend"\n'
-        )
-
-        apport.hookutils.attach_mac_events(report, "/usr/sbin/cupsd")
-        self.assertEqual(report["Tags"], "apparmor")
-
     def test_recent_syslog_overflow(self) -> None:
         """recent_syslog on a huge file"""
         log = os.path.join(self.workdir, "syslog")
