@@ -15,10 +15,10 @@
 
 import argparse
 import collections
+import contextlib
 import datetime
 import grp
 import os
-import pathlib
 import resource
 import shutil
 import signal
@@ -31,10 +31,12 @@ import textwrap
 import time
 import typing
 import unittest
-from collections.abc import Callable
+from collections.abc import Callable, Iterator
+from pathlib import Path
 from unittest.mock import MagicMock
 
 import psutil
+import pytest
 
 import apport.fileutils
 from tests.helper import (
@@ -56,6 +58,64 @@ except ImportError as import_error:
 APPORT_PATH = get_data_directory() / "apport"
 apport_binary = import_module_from_file(APPORT_PATH)
 
+
+@contextlib.contextmanager
+def create_dropsuid() -> Iterator[str]:
+    """Compiles a suid binary that immediately drops privilege then sleeps."""
+    DROPSUID_SOURCE = """
+        #include <unistd.h>
+        #include <stdio.h>
+        #include <errno.h>
+
+        int main() {
+            int euid = geteuid();
+            int uid = getuid();
+
+            // We need to be suid
+            if (uid == euid) {
+                fprintf(stderr, "uid: %d, euid: %d\\n", uid, euid);
+                return 1;
+            }
+            // This call is supposed to succeed?!
+            if (seteuid(uid)) {
+                fprintf(stderr, "errno: %d\\n", errno);
+                return 2;
+            }
+            // We actually check that it succeeded.
+            if (geteuid() != uid)
+                return 3;
+            sleep(60);
+            return 0;
+        }
+    """
+    if not os.path.exists("/usr/bin/gcc"):
+        pytest.skip("This test needs GCC available")
+    with tempfile.TemporaryDirectory(dir="/var/tmp") as d:
+        tempdir = Path(d)
+        source = tempdir / "dropsuid.c"
+        source.write_text(DROPSUID_SOURCE)
+        binary = tempdir / "dropsuid"
+        cmd = ["/usr/bin/gcc", "-g", str(source), "-o", str(binary)]
+        subprocess.run(cmd, check=True)
+        # Grant everyone read permission on the directory!
+        os.chmod(tempdir, 0o755)
+        os.chmod(binary, 0o4755)
+        yield str(binary)
+
+
+@contextlib.contextmanager
+def create_suid(tmpdir: str = "/var/tmp") -> Iterator[str]:
+    """Creates a `sleep` suid binary in a subdirectory of `tmpdir`."""
+    src_bin = os.path.realpath("/bin/sleep")
+    with tempfile.TemporaryDirectory(dir=tmpdir) as tempdir:
+        binary = f"{tempdir}/sleep"
+        shutil.copy(src_bin, binary)
+        # Grant everyone read permission on the directory!
+        os.chmod(tempdir, 0o755)
+        os.chmod(binary, 0o4755)
+        yield binary
+
+
 MAIL_UID = 8
 test_package = "coreutils"
 test_source = "coreutils"
@@ -329,9 +389,9 @@ class T(unittest.TestCase):
         # absolute path
         self.do_crash(command=local_exe, args=[], expect_report=False)
 
-        # relative path
-        os.chdir(self.workdir)
-        self.do_crash(command="./myscript", args=[], expect_report=False)
+        self.do_crash(
+            command="./myscript", args=[], expect_report=False, cwd=self.workdir
+        )
 
     def test_unsupported_arguments_no_stderr(self) -> None:
         """Write failure to log file when stderr is missing.
@@ -684,74 +744,47 @@ class T(unittest.TestCase):
     @unittest.skipIf(os.geteuid() != 0, "this test needs to be run as root")
     def test_crash_setuid_keep(self) -> None:
         """Report generation for setuid program which stays root."""
-        # create suid root executable in a path we can modify which apport
-        # regards as likely packaged
-        (fd, myexe) = tempfile.mkstemp(dir="/var/tmp")
-        self.addCleanup(os.unlink, myexe)
-        with open(self.TEST_EXECUTABLE, "rb") as f:
-            os.write(fd, f.read())
-        os.close(fd)
-        os.chmod(myexe, 0o4755)
+        with create_suid() as suid:
+            resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
+            # if a user can crash a suid root binary, it should not create
+            # core files
+            # run test program in /run (which should only be writable to root)
+            self.do_crash(command=suid, uid=MAIL_UID, suid_dumpable=2, cwd="/run")
 
-        # run test program in /run (which should only be writable to root)
-        os.chdir("/run")
-
-        resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
-
-        # if a user can crash a suid root binary, it should not create
-        # core files
-        self.do_crash(command=myexe, uid=MAIL_UID, suid_dumpable=2)
-
-    @unittest.skipUnless(os.path.exists("/bin/ping"), "this test needs /bin/ping")
     @unittest.skipIf(os.geteuid() != 0, "this test needs to be run as root")
     def test_crash_suid_dumpable_debug(self) -> None:
-        """Report generation for setuid program with suid_dumpable set to 1.
-
-        ping has cap_net_raw=ep and therefore do_crash needs root.
-        """
-        resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
-
+        """Report generation for setuid program with suid_dumpable set to 1."""
         # if a user can crash a suid root binary, it should not create
         # core files if /proc/sys/fs/suid_dumpable is set to 1 ("debug")
-        self.do_crash(
-            command="/bin/ping", args=["127.0.0.1"], uid=MAIL_UID, suid_dumpable=1
-        )
+        with create_suid() as suid:
+            resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
+            self.do_crash(command=suid, uid=MAIL_UID, suid_dumpable=1)
 
-    @unittest.skipUnless(os.path.exists("/bin/ping"), "this test needs /bin/ping")
     @unittest.skipIf(os.geteuid() != 0, "this test needs to be run as root")
     def test_crash_setuid_drop(self) -> None:
         """Report generation for setuid program which drops root."""
-        resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
-
-        # if a user can crash a suid root binary, it should not create
-        # core files
-        self.do_crash(
-            command="/bin/ping", args=["127.0.0.1"], uid=MAIL_UID, suid_dumpable=2
-        )
+        with create_dropsuid() as dropsuid:
+            resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
+            # if a user can crash a suid root binary, it should not create
+            # core files
+            self.do_crash(command=dropsuid, uid=MAIL_UID, suid_dumpable=2)
 
     @unittest.skipIf(os.geteuid() != 0, "this test needs to be run as root")
     def test_crash_setuid_unpackaged(self) -> None:
         """Report generation for unpackaged setuid program."""
         # create suid root executable in a path we can modify which apport
         # regards as not packaged
-        (fd, myexe) = tempfile.mkstemp(dir="/tmp")
-        self.addCleanup(os.unlink, myexe)
-        with open(self.TEST_EXECUTABLE, "rb") as f:
-            os.write(fd, f.read())
-        os.close(fd)
-        os.chmod(myexe, 0o4755)
-
-        resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
-
-        # if a user can crash a suid root binary, it should not create
-        # core files
-        self.do_crash(
-            command=myexe,
-            expect_corefile=False,
-            expect_report=False,
-            uid=MAIL_UID,
-            suid_dumpable=2,
-        )
+        with create_suid(tmpdir="/tmp") as suid:
+            resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
+            # if a user can crash a suid root binary, it should not create
+            # core files
+            self.do_crash(
+                command=suid,
+                expect_corefile=False,
+                expect_report=False,
+                uid=MAIL_UID,
+                suid_dumpable=2,
+            )
 
     def test_coredump_from_socket(self):
         """Forward a core dump through a socket.
@@ -777,25 +810,21 @@ class T(unittest.TestCase):
             via_socket=True,
         )
 
-    @unittest.skipUnless(os.path.exists("/bin/ping"), "this test needs /bin/ping")
     @unittest.skipIf(os.geteuid() != 0, "this test needs to be run as root")
     def test_crash_setuid_drop_via_socket(self):
         """Report generation via socket for setuid program which drops root."""
-        resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
-        self.do_crash(
-            command="/bin/ping",
-            args=["127.0.0.1"],
-            uid=MAIL_UID,
-            suid_dumpable=2,
-            via_socket=True,
-        )
+        with create_dropsuid() as dropsuid:
+            resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
+            self.do_crash(
+                command=dropsuid, uid=MAIL_UID, suid_dumpable=2, via_socket=True
+            )
 
-        # check crash report
-        report = apport.Report()
-        with open(self.test_report, "rb") as report_file:
-            report.load(report_file)
-        self.assertEqual(report["Signal"], "11")
-        self.assertEqual(report["ExecutablePath"], os.path.realpath("/bin/ping"))
+            # check crash report
+            report = apport.Report()
+            with open(self.test_report, "rb") as report_file:
+                report.load(report_file)
+            self.assertEqual(report["Signal"], "11")
+            self.assertEqual(report["ExecutablePath"], dropsuid)
 
     @unittest.mock.patch("os.readlink")
     def test_is_not_same_ns(self, readlink_mock: MagicMock) -> None:
@@ -829,7 +858,7 @@ class T(unittest.TestCase):
     def test_crash_apport_from_systemd_coredump(self, reader_mock: MagicMock) -> None:
         """Report generation with apport from systemd-coredump."""
         with tempfile.TemporaryDirectory() as tmpdir, run_test_executable() as pid:
-            coredump_file = pathlib.Path(tmpdir) / "core.zst"
+            coredump_file = Path(tmpdir) / "core.zst"
             coredump_file.write_text("mocked core")
 
             now = datetime.datetime.now(tz=datetime.timezone.utc)
@@ -1035,8 +1064,7 @@ class T(unittest.TestCase):
         # set UTF-8 environment variable, to check proper parsing in apport
         os.putenv("utf8trap", b"\xc3\xa0\xc3\xa4")
         # caller needs to call .wait(), pylint: disable=consider-using-with
-        # False positive, see https://github.com/PyCQA/pylint/issues/7092
-        process = subprocess.Popen(  # pylint: disable=unexpected-keyword-arg
+        process = subprocess.Popen(
             [command] + args, env=env, stdout=subprocess.DEVNULL, user=uid
         )
 
@@ -1076,7 +1104,7 @@ class T(unittest.TestCase):
 
         wait_sleep_mock.assert_not_called()
 
-    # pylint: disable-next=too-many-arguments
+    # pylint: disable-next=too-many-arguments,too-many-positional-arguments
     def do_crash(
         self,
         expect_corefile: bool = False,
@@ -1090,6 +1118,7 @@ class T(unittest.TestCase):
         hook_before_apport: Callable | None = None,
         expect_report: bool = True,
         via_socket: bool = False,
+        **kwargs: typing.Any,
     ) -> None:
         # TODO: Split into smaller functions/methods
         # pylint: disable=too-many-branches,too-many-locals,too-many-statements
@@ -1139,7 +1168,7 @@ class T(unittest.TestCase):
                 self.gdb_command(command, args, gdb_core_file, uid),
                 env={"HOME": self.workdir},
                 stdin=subprocess.PIPE,
-                stdout=subprocess.DEVNULL,  # ping produces output!
+                **kwargs,
             )
         except FileNotFoundError as error:
             self.skipTest(f"{error.filename} not available")
